jax-cosmo documentation
=======================

A differentiable and GPU accelerated cosmology library in JAX.

Checkout the `jax-cosmo GitHub page <https://github.com/DifferentiableUniverseInitiative/jax_cosmo>`_.

Install jax-cosmo
-----------------

Because jax-cosmo is written in plain Python, installing it is trivial:

      $ pip install jax-cosmo

That's all there is to it.

.. toctree::
   :maxdepth: 1
   :caption: Tutorials

   notebooks/jax-cosmo-intro.ipynb
   notebooks/CCL_comparison.ipynb

.. toctree::
   :maxdepth: 3
   :caption: API documentation

   api/modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
